﻿/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2007 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Galician language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Ocultar Ferramentas",
ToolbarExpand		: "Mostrar Ferramentas",

// Toolbar Items and Context Menu
Save				: "Gardar",
NewPage				: "Nova Páxina",
Preview				: "Vista Previa",
Cut					: "Cortar",
Copy				: "Copiar",
Paste				: "Pegar",
PasteText			: "Pegar como texto plano",
PasteWord			: "Pegar dende Word",
Print				: "Imprimir",
SelectAll			: "Seleccionar todo",
RemoveFormat		: "Eliminar Formato",
InsertLinkLbl		: "Ligazón",
InsertLink			: "Inserir/Editar Ligazón",
RemoveLink			: "Eliminar Ligazón",
Anchor				: "Inserir/Editar Referencia",
InsertImageLbl		: "Imaxe",
InsertImage			: "Inserir/Editar Imaxe",
InsertFlashLbl		: "Flash",
InsertFlash			: "Inserir/Editar Flash",
InsertTableLbl		: "Tabla",
InsertTable			: "Inserir/Editar Tabla",
InsertLineLbl		: "Liña",
InsertLine			: "Inserir Liña Horizontal",
InsertSpecialCharLbl: "Carácter Special",
InsertSpecialChar	: "Inserir Carácter Especial",
InsertSmileyLbl		: "Smiley",
InsertSmiley		: "Inserir Smiley",
About				: "Acerca de FCKeditor",
Bold				: "Negrita",
Italic				: "Cursiva",
Underline			: "Sub-raiado",
StrikeThrough		: "Tachado",
Subscript			: "Subíndice",
Superscript			: "Superíndice",
LeftJustify			: "Aliñar á Esquerda",
CenterJustify		: "Centrado",
RightJustify		: "Aliñar á Dereita",
BlockJustify		: "Xustificado",
DecreaseIndent		: "Disminuir Sangría",
IncreaseIndent		: "Aumentar Sangría",
Undo				: "Desfacer",
Redo				: "Refacer",
NumberedListLbl		: "Lista Numerada",
NumberedList		: "Inserir/Eliminar Lista Numerada",
BulletedListLbl		: "Marcas",
BulletedList		: "Inserir/Eliminar Marcas",
ShowTableBorders	: "Mostrar Bordes das Táboas",
ShowDetails			: "Mostrar Marcas Parágrafo",
Style				: "Estilo",
FontFormat			: "Formato",
Font				: "Tipo",
FontSize			: "Tamaño",
TextColor			: "Cor do Texto",
BGColor				: "Cor do Fondo",
Source				: "Código Fonte",
Find				: "Procurar",
Replace				: "Substituir",
SpellCheck			: "Corrección Ortográfica",
UniversalKeyboard	: "Teclado Universal",
PageBreakLbl		: "Salto de Páxina",
PageBreak			: "Inserir Salto de Páxina",

Form			: "Formulario",
Checkbox		: "Cadro de Verificación",
RadioButton		: "Botón de Radio",
TextField		: "Campo de Texto",
Textarea		: "Área de Texto",
HiddenField		: "Campo Oculto",
Button			: "Botón",
SelectionField	: "Campo de Selección",
ImageButton		: "Botón de Imaxe",

FitWindow		: "Maximizar o tamaño do editor",

// Context Menu
EditLink			: "Editar Ligazón",
CellCM				: "Cela",
RowCM				: "Fila",
ColumnCM			: "Columna",
InsertRow			: "Inserir Fila",
DeleteRows			: "Borrar Filas",
InsertColumn		: "Inserir Columna",
DeleteColumns		: "Borrar Columnas",
InsertCell			: "Inserir Cela",
DeleteCells			: "Borrar Cela",
MergeCells			: "Unir Celas",
SplitCell			: "Partir Celas",
TableDelete			: "Borrar Táboa",
CellProperties		: "Propriedades da Cela",
TableProperties		: "Propriedades da Táboa",
ImageProperties		: "Propriedades Imaxe",
FlashProperties		: "Propriedades Flash",

AnchorProp			: "Propriedades da Referencia",
ButtonProp			: "Propriedades do Botón",
CheckboxProp		: "Propriedades do Cadro de Verificación",
HiddenFieldProp		: "Propriedades do Campo Oculto",
RadioButtonProp		: "Propriedades do Botón de Radio",
ImageButtonProp		: "Propriedades do Botón de Imaxe",
TextFieldProp		: "Propriedades do Campo de Texto",
SelectionFieldProp	: "Propriedades do Campo de Selección",
TextareaProp		: "Propriedades da Área de Texto",
FormProp			: "Propriedades do Formulario",

FontFormats			: "Normal;Formateado;Enderezo;Enacabezado 1;Encabezado 2;Encabezado 3;Encabezado 4;Encabezado 5;Encabezado 6;Paragraph (DIV)",		//REVIEW : Check _getfontformat.html

// Alerts and Messages
ProcessingXHTML		: "Procesando XHTML. Por facor, agarde...",
Done				: "Feiro",
PasteWordConfirm	: "Parece que o texto que quere pegar está copiado do Word.¿Quere limpar o formato antes de pegalo?",
NotCompatiblePaste	: "Este comando está disponible para Internet Explorer versión 5.5 ou superior. ¿Quere pegalo sen limpar o formato?",
UnknownToolbarItem	: "Ítem de ferramentas descoñecido \"%1\"",
UnknownCommand		: "Nome de comando descoñecido \"%1\"",
NotImplemented		: "Comando non implementado",
UnknownToolbarSet	: "O conxunto de ferramentas \"%1\" non existe",
NoActiveX			: "As opcións de seguridade do seu navegador poderían limitar algunha das características de editor. Debe activar a opción \"Executar controis ActiveX e plug-ins\". Pode notar que faltan características e experimentar erros",
BrowseServerBlocked : "Non se poido abrir o navegador de recursos. Asegúrese de que están desactivados os bloqueadores de xanelas emerxentes",
DialogBlocked		: "Non foi posible abrir a xanela de diálogo. Asegúrese de que están desactivados os bloqueadores de xanelas emerxentes",

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Cancelar",
DlgBtnClose			: "Pechar",
DlgBtnBrowseServer	: "Navegar no Servidor",
DlgAdvancedTag		: "Advanzado",
DlgOpOther			: "<Outro>",
DlgInfoTab			: "Info",
DlgAlertUrl			: "Por favor, insira a URL",

// General Dialogs Labels
DlgGenNotSet		: "<non definido>",
DlgGenId			: "Id",
DlgGenLangDir		: "Orientación do Idioma",
DlgGenLangDirLtr	: "Esquerda a Dereita (LTR)",
DlgGenLangDirRtl	: "Dereita a Esquerda (RTL)",
DlgGenLangCode		: "Código do Idioma",
DlgGenAccessKey		: "Chave de Acceso",
DlgGenName			: "Nome",
DlgGenTabIndex		: "Índice de Tabulación",
DlgGenLongDescr		: "Descrición Completa da URL",
DlgGenClass			: "Clases da Folla de Estilos",
DlgGenTitle			: "Título",
DlgGenContType		: "Tipo de Contido",
DlgGenLinkCharset	: "Fonte de Caracteres Vinculado",
DlgGenStyle			: "Estilo",

// Image Dialog
DlgImgTitle			: "Propriedades da Imaxe",
DlgImgInfoTab		: "Información da Imaxe",
DlgImgBtnUpload		: "Enviar ó Servidor",
DlgImgURL			: "URL",
DlgImgUpload		: "Carregar",
DlgImgAlt			: "Texto Alternativo",
DlgImgWidth			: "Largura",
DlgImgHeight		: "Altura",
DlgImgLockRatio		: "Proporcional",
DlgBtnResetSize		: "Tamaño Orixinal",
DlgImgBorder		: "Límite",
DlgImgHSpace		: "Esp. Horiz.",
DlgImgVSpace		: "Esp. Vert.",
DlgImgAlign			: "Aliñamento",
DlgImgAlignLeft		: "Esquerda",
DlgImgAlignAbsBottom: "Abs Inferior",
DlgImgAlignAbsMiddle: "Abs Centro",
DlgImgAlignBaseline	: "Liña Base",
DlgImgAlignBottom	: "Pé",
DlgImgAlignMiddle	: "Centro",
DlgImgAlignRight	: "Dereita",
DlgImgAlignTextTop	: "Tope do Texto",
DlgImgAlignTop		: "Tope",
DlgImgPreview		: "Vista Previa",
DlgImgAlertUrl		: "Por favor, escriba a URL da imaxe",
DlgImgLinkTab		: "Ligazón",

// Flash Dialog
DlgFlashTitle		: "Propriedades Flash",
DlgFlashChkPlay		: "Auto Execución",
DlgFlashChkLoop		: "Bucle",
DlgFlashChkMenu		: "Activar Menú Flash",
DlgFlashScale		: "Escalar",
DlgFlashScaleAll	: "Amosar Todo",
DlgFlashScaleNoBorder	: "Sen Borde",
DlgFlashScaleFit	: "Encaixar axustando",

// Link Dialog
DlgLnkWindowTitle	: "Ligazón",
DlgLnkInfoTab		: "Información da Ligazón",
DlgLnkTargetTab		: "Referencia a esta páxina",

DlgLnkType			: "Tipo de Ligazón",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Referencia nesta páxina",
DlgLnkTypeEMail		: "E-Mail",
DlgLnkProto			: "Protocolo",
DlgLnkProtoOther	: "<outro>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Seleccionar unha Referencia",
DlgLnkAnchorByName	: "Por Nome de Referencia",
DlgLnkAnchorById	: "Por Element Id",
DlgLnkNoAnchors		: "<Non hai referencias disponibles no documento>",		//REVIEW : Change < and > with ( and )
DlgLnkEMail			: "Enderezo de E-Mail",
DlgLnkEMailSubject	: "Asunto do Mensaxe",
DlgLnkEMailBody		: "Corpo do Mensaxe",
DlgLnkUpload		: "Carregar",
DlgLnkBtnUpload		: "Enviar ó servidor",

DlgLnkTarget		: "Destino",
DlgLnkTargetFrame	: "<frame>",
DlgLnkTargetPopup	: "<Xanela Emerxente>",
DlgLnkTargetBlank	: "Nova Xanela (_blank)",
DlgLnkTargetParent	: "Xanela Pai (_parent)",
DlgLnkTargetSelf	: "Mesma Xanela (_self)",
DlgLnkTargetTop		: "Xanela Primaria (_top)",
DlgLnkTargetFrameName	: "Nome do Marco Destino",
DlgLnkPopWinName	: "Nome da Xanela Emerxente",
DlgLnkPopWinFeat	: "Características da Xanela Emerxente",
DlgLnkPopResize		: "Axustable",
DlgLnkPopLocation	: "Barra de Localización",
DlgLnkPopMenu		: "Barra de Menú",
DlgLnkPopScroll		: "Barras de Desplazamento",
DlgLnkPopStatus		: "Barra de Estado",
DlgLnkPopToolbar	: "Barra de Ferramentas",
DlgLnkPopFullScrn	: "A Toda Pantalla (IE)",
DlgLnkPopDependent	: "Dependente (Netscape)",
DlgLnkPopWidth		: "Largura",
DlgLnkPopHeight		: "Altura",
DlgLnkPopLeft		: "Posición Esquerda",
DlgLnkPopTop		: "Posición dende Arriba",

DlnLnkMsgNoUrl		: "Por favor, escriba a ligazón URL",
DlnLnkMsgNoEMail	: "Por favor, escriba o enderezo de e-mail",
DlnLnkMsgNoAnchor	: "Por favor, seleccione un destino",
DlnLnkMsgInvPopName	: "The popup name must begin with an alphabetic character and must not contain spaces",	//MISSING

// Color Dialog
DlgColorTitle		: "Seleccionar Color",
DlgColorBtnClear	: "Nengunha",
DlgColorHighlight	: "Destacado",
DlgColorSelected	: "Seleccionado",

// Smiley Dialog
DlgSmileyTitle		: "Inserte un Smiley",

// Special Character Dialog
DlgSpecialCharTitle	: "Seleccione Caracter Especial",

// Table Dialog
DlgTableTitle		: "Propiedades da Táboa",
DlgTableRows		: "Filas",
DlgTableColumns		: "Columnas",
DlgTableBorder		: "Tamaño do Borde",
DlgTableAlign		: "Aliñamento",
DlgTableAlignNotSet	: "<Non Definido>",
DlgTableAlignLeft	: "Esquerda",
DlgTableAlignCenter	: "Centro",
DlgTableAlignRight	: "Ereita",
DlgTableWidth		: "Largura",
DlgTableWidthPx		: "pixels",
DlgTableWidthPc		: "percent",
DlgTableHeight		: "Altura",
DlgTableCellSpace	: "Marxe entre Celas",
DlgTableCellPad		: "Marxe interior",
DlgTableCaption		: "Título",
DlgTableSummary		: "Sumario",

// Table Cell Dialog
DlgCellTitle		: "Propriedades da Cela",
DlgCellWidth		: "Largura",
DlgCellWidthPx		: "pixels",
DlgCellWidthPc		: "percent",
DlgCellHeight		: "Altura",
DlgCellWordWrap		: "Axustar Liñas",
DlgCellWordWrapNotSet	: "<Non Definido>",
DlgCellWordWrapYes	: "Si",
DlgCellWordWrapNo	: "Non",
DlgCellHorAlign		: "Aliñamento Horizontal",
DlgCellHorAlignNotSet	: "<Non definido>",
DlgCellHorAlignLeft	: "Esquerda",
DlgCellHorAlignCenter	: "Centro",
DlgCellHorAlignRight: "Dereita",
DlgCellVerAlign		: "Aliñamento Vertical",
DlgCellVerAlignNotSet	: "<Non definido>",
DlgCellVerAlignTop	: "Arriba",
DlgCellVerAlignMiddle	: "Medio",
DlgCellVerAlignBottom	: "Abaixo",
DlgCellVerAlignBaseline	: "Liña de Base",
DlgCellRowSpan		: "Ocupar Filas",
DlgCellCollSpan		: "Ocupar Columnas",
DlgCellBackColor	: "Color de Fondo",
DlgCellBorderColor	: "Color de Borde",
DlgCellBtnSelect	: "Seleccionar...",

// Find Dialog
DlgFindTitle		: "Procurar",
DlgFindFindBtn		: "Procurar",
DlgFindNotFoundMsg	: "Non te atopou o texto indicado.",

// Replace Dialog
DlgReplaceTitle			: "Substituir",
DlgReplaceFindLbl		: "Texto a procurar:",
DlgReplaceReplaceLbl	: "Substituir con:",
DlgReplaceCaseChk		: "Coincidir Mai./min.",
DlgReplaceReplaceBtn	: "Substituir",
DlgReplaceReplAllBtn	: "Substitiur Todo",
DlgReplaceWordChk		: "Coincidir con toda a palabra",

// Paste Operations / Dialog
PasteErrorCut	: "Os axustes de seguridade do seu navegador non permiten que o editor realice automáticamente as tarefas de corte. Por favor, use o teclado para iso (Ctrl+X).",
PasteErrorCopy	: "Os axustes de seguridade do seu navegador non permiten que o editor realice automáticamente as tarefas de copia. Por favor, use o teclado para iso (Ctrl+C).",

PasteAsText		: "Pegar como texto plano",
PasteFromWord	: "Pegar dende Word",

DlgPasteMsg2	: "Por favor, pegue dentro do seguinte cadro usando o teclado (<STRONG>Ctrl+V</STRONG>) e pulse <STRONG>OK</STRONG>.",
DlgPasteSec		: "Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.",	//MISSING
DlgPasteIgnoreFont		: "Ignorar as definicións de Tipografía",
DlgPasteRemoveStyles	: "Eliminar as definicións de Estilos",
DlgPasteCleanBox		: "Limpar o Cadro",

// Color Picker
ColorAutomatic	: "Automático",
ColorMoreColors	: "Máis Cores...",

// Document Properties
DocProps		: "Propriedades do Documento",

// Anchor Dialog
DlgAnchorTitle		: "Propriedades da Referencia",
DlgAnchorName		: "Nome da Referencia",
DlgAnchorErrorName	: "Por favor, escriba o nome da referencia",

// Speller Pages Dialog
DlgSpellNotInDic		: "Non está no diccionario",
DlgSpellChangeTo		: "Cambiar a",
DlgSpellBtnIgnore		: "Ignorar",
DlgSpellBtnIgnoreAll	: "Ignorar Todas",
DlgSpellBtnReplace		: "Substituir",
DlgSpellBtnReplaceAll	: "Substituir Todas",
DlgSpellBtnUndo			: "Desfacer",
DlgSpellNoSuggestions	: "- Sen candidatos -",
DlgSpellProgress		: "Corrección ortográfica en progreso...",
DlgSpellNoMispell		: "Corrección ortográfica rematada: Non se atoparon erros",
DlgSpellNoChanges		: "Corrección ortográfica rematada: Non se substituiu nengunha verba",
DlgSpellOneChange		: "Corrección ortográfica rematada: Unha verba substituida",
DlgSpellManyChanges		: "Corrección ortográfica rematada: %1 verbas substituidas",

IeSpellDownload			: "O corrector ortográfico non está instalado. ¿Quere descargalo agora?",

// Button Dialog
DlgButtonText		: "Texto (Valor)",
DlgButtonType		: "Tipo",
DlgButtonTypeBtn	: "Button",	//MISSING
DlgButtonTypeSbm	: "Submit",	//MISSING
DlgButtonTypeRst	: "Reset",	//MISSING

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Nome",
DlgCheckboxValue	: "Valor",
DlgCheckboxSelected	: "Seleccionado",

// Form Dialog
DlgFormName		: "Nome",
DlgFormAction	: "Acción",
DlgFormMethod	: "Método",

// Select Field Dialog
DlgSelectName		: "Nome",
DlgSelectValue		: "Valor",
DlgSelectSize		: "Tamaño",
DlgSelectLines		: "liñas",
DlgSelectChkMulti	: "Permitir múltiples seleccións",
DlgSelectOpAvail	: "Opcións Disponibles",
DlgSelectOpText		: "Texto",
DlgSelectOpValue	: "Valor",
DlgSelectBtnAdd		: "Engadir",
DlgSelectBtnModify	: "Modificar",
DlgSelectBtnUp		: "Subir",
DlgSelectBtnDown	: "Baixar",
DlgSelectBtnSetValue : "Definir como valor por defecto",
DlgSelectBtnDelete	: "Borrar",

// Textarea Dialog
DlgTextareaName	: "Nome",
DlgTextareaCols	: "Columnas",
DlgTextareaRows	: "Filas",

// Text Field Dialog
DlgTextName			: "Nome",
DlgTextValue		: "Valor",
DlgTextCharWidth	: "Tamaño do Caracter",
DlgTextMaxChars		: "Máximo de Caracteres",
DlgTextType			: "Tipo",
DlgTextTypeText		: "Texto",
DlgTextTypePass		: "Chave",

// Hidden Field Dialog
DlgHiddenName	: "Nome",
DlgHiddenValue	: "Valor",

// Bulleted List Dialog
BulletedListProp	: "Propriedades das Marcas",
NumberedListProp	: "Propriedades da Lista de Numeración",
DlgLstStart			: "Start",	//MISSING
DlgLstType			: "Tipo",
DlgLstTypeCircle	: "Círculo",
DlgLstTypeDisc		: "Disco",
DlgLstTypeSquare	: "Cuadrado",
DlgLstTypeNumbers	: "Números (1, 2, 3)",
DlgLstTypeLCase		: "Letras Minúsculas (a, b, c)",
DlgLstTypeUCase		: "Letras Maiúsculas (A, B, C)",
DlgLstTypeSRoman	: "Números Romanos en minúscula (i, ii, iii)",
DlgLstTypeLRoman	: "Números Romanos en Maiúscula (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Xeral",
DlgDocBackTab		: "Fondo",
DlgDocColorsTab		: "Cores e Marxes",
DlgDocMetaTab		: "Meta Data",

DlgDocPageTitle		: "Título da Páxina",
DlgDocLangDir		: "Orientación do Idioma",
DlgDocLangDirLTR	: "Esquerda a Dereita (LTR)",
DlgDocLangDirRTL	: "Dereita a Esquerda (RTL)",
DlgDocLangCode		: "Código de Idioma",
DlgDocCharSet		: "Codificación do Xogo de Caracteres",
DlgDocCharSetCE		: "Central European",	//MISSING
DlgDocCharSetCT		: "Chinese Traditional (Big5)",	//MISSING
DlgDocCharSetCR		: "Cyrillic",	//MISSING
DlgDocCharSetGR		: "Greek",	//MISSING
DlgDocCharSetJP		: "Japanese",	//MISSING
DlgDocCharSetKR		: "Korean",	//MISSING
DlgDocCharSetTR		: "Turkish",	//MISSING
DlgDocCharSetUN		: "Unicode (UTF-8)",	//MISSING
DlgDocCharSetWE		: "Western European",	//MISSING
DlgDocCharSetOther	: "Outra Codificación do Xogo de Caracteres",

DlgDocDocType		: "Encabezado do Tipo de Documento",
DlgDocDocTypeOther	: "Outro Encabezado do Tipo de Documento",
DlgDocIncXHTML		: "Incluir Declaracións XHTML",
DlgDocBgColor		: "Cor de Fondo",
DlgDocBgImage		: "URL da Imaxe de Fondo",
DlgDocBgNoScroll	: "Fondo Fixo",
DlgDocCText			: "Texto",
DlgDocCLink			: "Ligazóns",
DlgDocCVisited		: "Ligazón Visitada",
DlgDocCActive		: "Ligazón Activa",
DlgDocMargins		: "Marxes da Páxina",
DlgDocMaTop			: "Arriba",
DlgDocMaLeft		: "Esquerda",
DlgDocMaRight		: "Dereita",
DlgDocMaBottom		: "Abaixo",
DlgDocMeIndex		: "Palabras Chave de Indexación do Documento (separadas por comas)",
DlgDocMeDescr		: "Descripción do Documento",
DlgDocMeAuthor		: "Autor",
DlgDocMeCopy		: "Copyright",
DlgDocPreview		: "Vista Previa",

// Templates Dialog
Templates			: "Plantillas",
DlgTemplatesTitle	: "Plantillas de Contido",
DlgTemplatesSelMsg	: "Por favor, seleccione a plantilla a abrir no editor<br>(o contido actual perderase):",
DlgTemplatesLoading	: "Cargando listado de plantillas. Por favor, espere...",
DlgTemplatesNoTpl	: "(Non hai plantillas definidas)",
DlgTemplatesReplace	: "Replace actual contents",	//MISSING

// About Dialog
DlgAboutAboutTab	: "Acerca de",
DlgAboutBrowserInfoTab	: "Información do Navegador",
DlgAboutLicenseTab	: "Licencia",
DlgAboutVersion		: "versión",
DlgAboutInfo		: "Para máis información visitar:"
};